from .chamber import Chamber


__title__ = '36-chambers'
__version__ = '0.0.1'
__author__ = 'Mike Goffin'
__license__ = 'MIT'
__copyright__ = 'Copyright 2017 Mike Goffin'

__all__ = [
    'Chamber'
]
